@@ -136,45 +136,3 @@ class RiskRelation(NetBoxModel):
         return reverse('plugins:users_and_computers:riskrelation', args=[self.pk])
 
 
-class RiskAssignment(WebhooksMixin, ChangeLoggedModel):
-    content_type = models.ForeignKey(
-        to=ContentType,
-        on_delete=models.CASCADE
-    )
-    object_id = models.PositiveBigIntegerField()
-    object = GenericForeignKey(
-        ct_field='content_type_0',
-        fk_field='object_id'
-    )
-    risk = models.ForeignKey(
-        to='users_and_computers.Risk',
-        on_delete=models.PROTECT,
-        related_name='risk_assignments_0'
-    )
-    relation = models.ForeignKey(
-        to='users_and_computers.RiskRelation',
-        on_delete=models.PROTECT,
-        related_name='risk_assignments_0'
-    )
-
-    clone_fields = ('content_type', 'object_id')
-
-    class Meta:
-        ordering = ['risk']
-        unique_together = ('content_type', 'object_id',
-                           'risk', 'relation')
-
-    def __str__(self):
-        return str(self.risk)
-
-    def get_absolute_url(self):
-        return reverse('plugins:users_and_computers:risk', args=[self.risk.pk])
-
-
-@receiver(post_delete, sender=Risk, dispatch_uid='del_risk_assignment')
-def del_assignments(sender, **kwargs):
-    content_type_id = ContentType.objects.get(model='risk').id
-    instance_id = kwargs.get('instance').id
-    objs = RiskAssignment.objects.filter(
-        object_id=instance_id, content_type=content_type_id)
-    objs.delete()
